==> blue_sandbox-5.184.1-py3-none-any.whl: blue_sandbox/list.py <==
list_of_experiments = {
    "palisades": {
        "ICON": "🧑🏽‍🚒",
        "title": "Post-disaster Land Cover Classification.",
        "url": "https://github.com/kamangir/blue-sandbox/blob/main/blue_sandbox/palisades/README.md",
        "marquee": "https://github.com/kamangir/assets/raw/main/blue-geo/Maxar-Open-Datacube.png?raw=true",
        "status": "🔥",
    },
    "sagesemseg": {
        "ICON": "🌀",
        "title": "A SemSeg (Semantic Segmenter) trained and deployed on AWS Sagemaker.",
        "url": "https://github.com/kamangir/blue-sandbox/blob/main/blue_sandbox/sagesemseg/README.md",
        "marquee": "https://github.com/kamangir/assets/blob/main/blue-sandbox/sagesemseg-predict.png?raw=true",
        "status": "⏸️",
    },
    "`@damages`": {
        "ICON": "🌐",
        "title": "Satellite imagery damage assessment workflow",
        "url": "https://github.com/kamangir/blue-sandbox/blob/main/blue_sandbox/microsoft_building_damage_assessment/README.md",
        "marquee": "https://github.com/kamangir/assets/raw/main/blue-sandbox/Maui-Hawaii-fires-Aug-23-ingest-2025-01-10-qqJqhm.png?raw=true",
        "status": "⏸️",
    },
    "cemetery": {
        "ICON": "🪦",
        "title": "An AI cemetery.",
        "url": "https://github.com/kamangir/blue-sandbox/blob/main/blue_sandbox/cemetery/README.md",
        "marquee": "https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true",
        "status": "🪦",
    },
    "template": {
        "ICON": "",
        "title": "",
        "url": "",
        "marquee": "https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true",
        "status": "🎰",
    },
}

==> blue_sandbox-5.292.1-py3-none-any.whl: blue_sandbox/list.py <==
list_of_experiments = {
    "palisades": {
        "ICON": "🧑🏽‍🚒",
        "title": "Geospatial AI for Post-Disaster Damage Assessment using Maxar Open Data.",
        "url": "https://github.com/kamangir/palisades",
        "marquee": "https://github.com/kamangir/assets/blob/main/palisades/predict-datacube-maxar_open_data-WildFires-LosAngeles-Jan-2025-11-031311102213-103001010B9A1B00-2025-01-20-x54yb0/640.gif?raw=true",
        "status": "🎓",
    },
    "sagesemseg": {
        "ICON": "🌀",
        "title": "A SemSeg (Semantic Segmenter) trained and deployed on AWS Sagemaker.",
        "url": "https://github.com/kamangir/blue-sandbox/blob/main/blue_sandbox/sagesemseg/README.md",
        "marquee": "https://github.com/kamangir/assets/blob/main/blue-sandbox/sagesemseg-predict.png?raw=true",
        "status": "⏸️",
    },
    "`@damages`": {
        "ICON": "🌐",
        "title": "Satellite imagery damage assessment workflow",
        "url": "https://github.com/kamangir/blue-sandbox/blob/main/blue_sandbox/microsoft_building_damage_assessment/README.md",
        "marquee": "https://github.com/kamangir/assets/raw/main/blue-sandbox/Maui-Hawaii-fires-Aug-23-ingest-2025-01-10-qqJqhm.png?raw=true",
        "status": "⏸️",
    },
    "cemetery": {
        "ICON": "🪦",
        "title": "An AI cemetery.",
        "url": "https://github.com/kamangir/blue-sandbox/blob/main/blue_sandbox/cemetery/README.md",
        "marquee": "https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true",
        "status": "🪦",
    },
    "template": {
        "ICON": "",
        "title": "",
        "url": "",
        "marquee": "https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true",
        "status": "🎰",
    },
}
